.. _devguide:

Developer Guide
===============

This guide sheds light on new and reusable subsystems developed in ``datalad-next``.
The target audience are developers that intend to build up on or use functionality provided by this extension.

.. toctree::
   :maxdepth: 2

   constraints.rst
   contributing.rst
